import { __extends, __decorate, __metadata, __param } from 'tslib';
import { CommonModule } from '@angular/common';
import { EventEmitter, Input, Output, Component, Optional, Injector, isDevMode, Pipe, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR, AbstractControl, FormGroup, Validators, ControlContainer, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { CalendarValueAccessor, FormFieldDirective, PropertyMetadata, metaKeyModel, ModalService, Property, Model, FormMaker, BaseControlWithinForm, SelectValueAccessor, ToastService, TooltipService, UiModelModule } from '@ui-model/angular';
import { Toggle, Pagination, TableSorter } from '@ui-model/common';
import { isFunction, isString } from 'util';
import { SortOrder, Rect, isFunction as isFunction$1 } from '@ui-model/core';
import { Subject } from 'rxjs';
import { skipWhile, debounceTime, tap } from 'rxjs/operators';

var CalendarComponent = /** @class */ (function (_super) {
    __extends(CalendarComponent, _super);
    function CalendarComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.change = new EventEmitter();
        return _this;
    }
    CalendarComponent_1 = CalendarComponent;
    CalendarComponent.prototype.close = function () {
        this.change.emit(this.value);
    };
    var CalendarComponent_1;
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], CalendarComponent.prototype, "disabled", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], CalendarComponent.prototype, "change", void 0);
    CalendarComponent = CalendarComponent_1 = __decorate([
        Component({
            selector: 'ui-calendar',
            template: "<table [class.diabled]=\"disabled\">\n  <caption>\n    <div>\n      <a (click)=\"goToPrevMonth()\" href=\"javascript:void(0)\" title=\"Previous Month\">\n        <i class=\"fa fa-chevron-left\"></i>\n      </a>\n      <select [(ngModel)]=\"month\" class=\"form-control\" name=\"month\">\n        <option *ngFor=\"let month of monthNames;let index = index\" [ngValue]=\"index\">{{month}}</option>\n      </select>\n      <select [(ngModel)]=\"year\" class=\"form-control\" name=\"year\">\n        <option *ngFor=\"let year of nearlyYears\" [ngValue]=\"year\">{{year}}</option>\n      </select>\n      <a (click)=\"clear()\" href=\"javascript:void(0)\" title=\"Clear\">\n        <i class=\"fa fa-close\"></i>\n      </a>\n      <a (click)=\"goToToday()\" href=\"javascript:void(0)\" title=\"Today\">\n        <i class=\"fa fa-map-marker\"></i>\n      </a>\n      <a (click)=\"goToNextMonth()\" href=\"javascript:void(0)\" title=\"Next Month\">\n        <i class=\"fa fa-chevron-right\"></i>\n      </a>\n    </div>\n  </caption>\n  <thead>\n  <tr>\n    <th></th>\n    <th *ngFor=\"let name of weekdayNames\">{{name}}</th>\n  </tr>\n  </thead>\n  <tbody>\n  <tr *ngFor=\"let week of weeks\">\n    <td class=\"week\">\n      {{week}}\n    </td>\n    <td *ngFor=\"let day of dates(week)\"\n        (click)=\"goTo(day); close()\"\n        [class.active]=\"isActive(day)\"\n        [class.other-month]=\"!inSameMonth(day)\"\n        [class.today]=\"isToday(day)\"\n        [class.weekend]=\"isWeekEnd(day)\"\n    >\n      {{day.getDate()}}\n    </td>\n  </tr>\n  </tbody>\n</table>\n<div *ngIf=\"disabled\" class=\"disabled-mask\"></div>\n",
            providers: [{
                    provide: NG_VALUE_ACCESSOR,
                    useExisting: CalendarComponent_1,
                    multi: true,
                }],
            styles: [":host{display:block;position:relative;overflow:hidden;border-radius:.25rem}.disabled-mask{position:absolute;top:0;left:0;width:100%;height:100%;background:rgba(173,181,189,.1)}caption{caption-side:top;padding:0;text-align:center}caption>div{display:table;width:100%}caption>div>*{display:table-cell;width:auto}caption>div>.form-control{border:none;width:50%}caption a{color:#adb5bd}caption a:focus,caption a:hover{color:#0056b3}.icon{vertical-align:middle}table{margin:auto}th{text-align:center}td{padding:.2em .5em;text-align:center;vertical-align:middle;cursor:pointer}td.week{padding-left:.2em;padding-right:.2em;color:#adb5bd;font-size:smaller;border-right:1px solid #dee2e6}td.weekend{color:#adb5bd}td.other-month{color:#dee2e6}td.today{color:#f8f9fa;background:#17a2b8}td.active{background:#007bff;color:#f8f9fa}"]
        })
    ], CalendarComponent);
    return CalendarComponent;
}(CalendarValueAccessor));

var DatePickerComponent = /** @class */ (function () {
    function DatePickerComponent() {
        this.toggle = new Toggle();
        this.disabled = false;
    }
    DatePickerComponent_1 = DatePickerComponent;
    Object.defineProperty(DatePickerComponent.prototype, "value", {
        get: function () {
            return this._value;
        },
        set: function (value) {
            this._value = value;
        },
        enumerable: true,
        configurable: true
    });
    DatePickerComponent.prototype.ngOnInit = function () {
    };
    DatePickerComponent.prototype.writeValue = function (obj) {
        this.value = obj;
    };
    DatePickerComponent.prototype.changed = function () {
        if (this._onChange) {
            this._onChange(this.value);
        }
    };
    DatePickerComponent.prototype.registerOnChange = function (fn) {
        this._onChange = fn;
    };
    DatePickerComponent.prototype.registerOnTouched = function (fn) {
        this._onTouched = fn;
    };
    DatePickerComponent.prototype.setDisabledState = function (isDisabled) {
        this.disabled = isDisabled;
    };
    DatePickerComponent.prototype.touched = function () {
        if (this._onTouched) {
            this._onTouched();
        }
    };
    var DatePickerComponent_1;
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], DatePickerComponent.prototype, "disabled", void 0);
    DatePickerComponent = DatePickerComponent_1 = __decorate([
        Component({
            selector: 'ui-date-picker',
            template: "<div (uiClickOutside)=\"toggle.close()\" class=\"dropdown\">\n  <div class=\"input-group\">\n    <input (ngModelChange)=\"changed()\" [(ngModel)]=\"value\" [disabled]=\"disabled\" class=\"form-control\" type=\"text\"\n           uiDateInput/>\n    <div class=\"input-group-append\">\n      <button (click)=\"toggle.toggle()\" [disabled]=\"disabled\" class=\"btn btn-primary\" type=\"button\">\n        <i class=\"fa fa-calendar\"></i>\n      </button>\n    </div>\n  </div>\n  <div *ngIf=\"!disabled && toggle.isOn\" class=\"dropdown-menu\">\n    <ui-calendar (change)=\"toggle.close()\" (ngModelChange)=\"changed()\" [(ngModel)]=\"value\" name=\"date\"></ui-calendar>\n  </div>\n</div>\n",
            providers: [
                { provide: NG_VALUE_ACCESSOR, multi: true, useExisting: DatePickerComponent_1 },
            ],
            styles: [":host{display:block}.dropdown .dropdown-menu{display:block;width:100%;margin-top:0;padding:1rem}"]
        }),
        __metadata("design:paramtypes", [])
    ], DatePickerComponent);
    return DatePickerComponent;
}());

var FieldErrorComponent = /** @class */ (function () {
    function FieldErrorComponent(formField) {
        this.formField = formField;
    }
    Object.defineProperty(FieldErrorComponent.prototype, "field", {
        get: function () {
            return this.controls[0];
        },
        set: function (value) {
            this.controls = [value];
        },
        enumerable: true,
        configurable: true
    });
    FieldErrorComponent.prototype.ngOnInit = function () {
        var _this = this;
        if (!this.formField) {
            return;
        }
        this.formField.changes$.subscribe(function (controls) { return _this.controls = controls; });
    };
    FieldErrorComponent.ctorParameters = function () { return [
        { type: FormFieldDirective, decorators: [{ type: Optional }] }
    ]; };
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], FieldErrorComponent.prototype, "messages", void 0);
    __decorate([
        Input(),
        __metadata("design:type", AbstractControl),
        __metadata("design:paramtypes", [AbstractControl])
    ], FieldErrorComponent.prototype, "field", null);
    FieldErrorComponent = __decorate([
        Component({
            selector: 'ui-field-error',
            template: "<div *ngFor=\"let control of controls\">\n  <div *ngIf=\"control.pending\" class=\"text-warning\">\n    <i class=\"fa fa-spinner fa-spin\"></i>\n    checking...\n  </div>\n  <ul *ngIf=\"!control.pristine && control.invalid && control.errors\" class=\"text-danger\">\n    <li *ngFor=\"let error of control.errors | objectToArray\"\n        [innerHTML]=\"error|fieldErrorMapper:messages|template:error|safeHtml\"></li>\n  </ul>\n</div>\n",
            styles: [":host{display:block}ul{margin-bottom:0}"]
        }),
        __param(0, Optional()),
        __metadata("design:paramtypes", [FormFieldDirective])
    ], FieldErrorComponent);
    return FieldErrorComponent;
}());

var FormArrayComponent = /** @class */ (function () {
    function FormArrayComponent() {
        this.readonly = false;
    }
    FormArrayComponent.prototype.ngOnInit = function () {
    };
    __decorate([
        Input(),
        __metadata("design:type", FormGroup)
    ], FormArrayComponent.prototype, "group", void 0);
    __decorate([
        Input(),
        __metadata("design:type", PropertyMetadata)
    ], FormArrayComponent.prototype, "field", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], FormArrayComponent.prototype, "readonly", void 0);
    FormArrayComponent = __decorate([
        Component({
            selector: 'ui-form-array',
            template: "<div *ngIf=\"field\" [formGroup]=\"group\">\n  <div #values=\"uiFormArray\" [formArrayName]=\"field.name\" class=\"form-group\">\n    <label *ngIf=\"field | fieldLabel\" for=\"values\">{{field | fieldLabel}}</label>\n    <div *ngFor=\"let control of values.items\" class=\"form-group\">\n      <div class=\"input-group\">\n        <input [formControl]=\"control\" class=\"form-control\" id=\"values\" name=\"values\" type=\"text\"/>\n        <div class=\"input-group-append\">\n          <button (click)=\"values.removeItem(control)\" [disabled]=\"control.disabled\" class=\"btn btn-primary\">\n            <i class=\"fa fa-close\"></i>\n          </button>\n        </div>\n      </div>\n      <ui-field-error [field]=\"control\"></ui-field-error>\n    </div>\n    <div>\n      <button (click)=\"values.createItem()\" [disabled]=\"group.disabled || group.root.disabled\" class=\"btn btn-primary\"\n              type=\"button\">\n        <i class=\"fa fa-plus-circle\"></i>\n        Add a new tag\n      </button>\n    </div>\n  </div>\n</div>\n",
            styles: [":host{display:block}"]
        }),
        __metadata("design:paramtypes", [])
    ], FormArrayComponent);
    return FormArrayComponent;
}());

var FormControlComponent = /** @class */ (function () {
    function FormControlComponent(injector) {
        this.injector = injector;
        this.readonly = false;
        this.uniqueId = ++FormControlComponent_1.latestUniqueId;
    }
    FormControlComponent_1 = FormControlComponent;
    Object.defineProperty(FormControlComponent.prototype, "control", {
        get: function () {
            if (!this.group || !this.field) {
                return;
            }
            return this.group.get(this.field.name);
        },
        enumerable: true,
        configurable: true
    });
    FormControlComponent.prototype.ngOnInit = function () {
    };
    FormControlComponent.prototype.isCustomEditor = function (field) {
        return isFunction(field.editor);
    };
    FormControlComponent.prototype.isInput = function (field) {
        return !field.editor || isString(field.editor) && field.editor !== 'textarea';
    };
    FormControlComponent.prototype.isTextArea = function (field) {
        return field.editor === 'textarea';
    };
    FormControlComponent.prototype.isRequired = function (field) {
        return field.validators && field.validators.indexOf(Validators.required) !== -1;
    };
    FormControlComponent.prototype.isPlainText = function (field) {
        return field.type === String;
    };
    FormControlComponent.prototype.isNumber = function (field) {
        return field.type === Number;
    };
    FormControlComponent.prototype.isDate = function (field) {
        return field.type === Date;
    };
    FormControlComponent.prototype.isCustomViewer = function (field) {
        return isFunction(field.viewer);
    };
    var FormControlComponent_1;
    FormControlComponent.ctorParameters = function () { return [
        { type: Injector }
    ]; };
    FormControlComponent.latestUniqueId = new Date().getTime();
    __decorate([
        Input(),
        __metadata("design:type", FormGroup)
    ], FormControlComponent.prototype, "group", void 0);
    __decorate([
        Input(),
        __metadata("design:type", PropertyMetadata)
    ], FormControlComponent.prototype, "field", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], FormControlComponent.prototype, "readonly", void 0);
    FormControlComponent = FormControlComponent_1 = __decorate([
        Component({
            selector: 'ui-form-control',
            template: "<div *ngIf=\"group && field\" [class.ui-required]=\"!readonly && isRequired(field)\" [formGroup]=\"group\"\n     class=\"form-group\">\n  <label *ngIf=\"field | fieldLabel\" for=\"_{{field.name}}_{{uniqueId}}\">{{field | fieldLabel}}</label>\n  <ng-container *ngIf=\"!readonly\">\n    <ng-container *ngIf=\"isInput(field)\">\n      <input [formControl]=\"control\" [readonly]=\"field.readonly\" [step]=\"field.editorInputs?.step\"\n             [type]=\"field.editor || 'text'\"\n             class=\"form-control\" id=\"_{{field.name}}_{{uniqueId}}\"/>\n    </ng-container>\n    <ng-container *ngIf=\"isTextArea(field)\">\n    <textarea [formControl]=\"control\" [readonly]=\"field.readonly\"\n              class=\"form-control\" id=\"_{{field.name}}_{{uniqueId}}\"></textarea>\n    </ng-container>\n    <div *ngIf=\"isCustomEditor(field)\" [ngComponentOutletInjector]=\"injector\" [ngComponentOutlet]=\"field.editor\"\n         [uiDynamicComponentInputs]=\"[field.editorInputs, {name: field.name, field: field}]\"></div>\n  </ng-container>\n  <div *ngIf=\"readonly\" class=\"form-control-plaintext\">\n    <div *ngIf=\"isCustomViewer(field)\" [ngComponentOutletInjector]=\"injector\" [ngComponentOutlet]=\"field.viewer\"\n         [uiDynamicComponentInputs]=\"[field.viewerInputs, {name: field.name, field: field}]\"></div>\n    <ng-container *ngIf=\"!isCustomViewer(field)\">\n      <div *ngIf=\"isPlainText(field)\">{{control.value | default : '-'}}</div>\n      <div *ngIf=\"isDate(field)\">{{control.value | date:field.viewerInputs?.format | default: '-' }}</div>\n      <div *ngIf=\"isNumber(field)\">\n        <ng-container *ngIf=\"field.viewerInputs?.format === 'percent'\">\n          {{control.value | percent | default: '(NaN)'}}\n        </ng-container>\n        <ng-container *ngIf=\"field.viewerInputs?.format !== 'percent'\">\n          {{control.value | number:field.viewerInputs?.format | default: '(NaN)'}}\n        </ng-container>\n      </div>\n    </ng-container>\n  </div>\n</div>\n",
            styles: [":host{display:block}"]
        }),
        __metadata("design:paramtypes", [Injector])
    ], FormControlComponent);
    return FormControlComponent;
}());

var FormGroupComponent = /** @class */ (function () {
    function FormGroupComponent() {
        this.readonly = false;
    }
    Object.defineProperty(FormGroupComponent.prototype, "form", {
        get: function () {
            return this.group && this.group[metaKeyModel];
        },
        enumerable: true,
        configurable: true
    });
    __decorate([
        Input(),
        __metadata("design:type", FormGroup)
    ], FormGroupComponent.prototype, "group", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], FormGroupComponent.prototype, "readonly", void 0);
    FormGroupComponent = __decorate([
        Component({
            selector: 'ui-form-group',
            template: "<div *ngIf=\"form && group\" [formGroup]=\"group\" class=\"row\">\n  <ng-container *ngFor=\"let field of form.properties\">\n    <div *ngIf=\"!field.hidden\" [ngClass]=\"field|fieldCss\" [uiFieldMetadata]=\"field\">\n      <ui-form-control *ngIf=\"field.isControl\" [field]=\"field\" [group]=\"group\" [readonly]=\"readonly\"></ui-form-control>\n      <ui-form-array *ngIf=\"field.isArray\" [field]=\"field\" [group]=\"group\" [readonly]=\"readonly\"></ui-form-array>\n      <fieldset *ngIf=\"field.isGroup\">\n        <legend>{{field.label}}</legend>\n        <ui-form-group [group]=\"group.get(field.name)\" [readonly]=\"readonly\"></ui-form-group>\n      </fieldset>\n      <ui-field-error [field]=\"group.get(field.name)\" [messages]=\"field.errors\"></ui-field-error>\n    </div>\n  </ng-container>\n</div>\n",
            styles: [":host{display:block}*+ui-field-error{position:relative;top:-1em}"]
        })
    ], FormGroupComponent);
    return FormGroupComponent;
}());

var ModalListComponent = /** @class */ (function () {
    function ModalListComponent(modal, injector) {
        this.modal = modal;
        this.injector = injector;
    }
    ModalListComponent.prototype.ngOnInit = function () {
    };
    ModalListComponent.ctorParameters = function () { return [
        { type: ModalService },
        { type: Injector }
    ]; };
    ModalListComponent = __decorate([
        Component({
            selector: 'ui-modal-list',
            template: "<ui-modal *ngFor=\"let item of modal.items\">\n  <ui-modal-info *ngIf=\"item.type === 'info'\"\n                 (cancel)=\"modal.cancel(item)\" (close)=\"modal.close(item, true)\" [icon]=\"item.icon\"\n                 [message]=\"item.message\" [title]=\"item.title\">\n  </ui-modal-info>\n  <ui-modal-success *ngIf=\"item.type === 'success'\"\n                    (cancel)=\"modal.cancel(item)\" (close)=\"modal.close(item, true)\" [icon]=\"item.icon\"\n                    [message]=\"item.message\" [title]=\"item.title\">\n  </ui-modal-success>\n  <ui-modal-warning *ngIf=\"item.type === 'warning'\"\n                    (cancel)=\"modal.cancel(item)\" (close)=\"modal.close(item, true)\" [icon]=\"item.icon\"\n                    [message]=\"item.message\" [title]=\"item.title\">\n  </ui-modal-warning>\n  <ui-modal-error *ngIf=\"item.type === 'error'\"\n                  (cancel)=\"modal.cancel(item)\" (close)=\"modal.close(item, true)\" [icon]=\"item.icon\"\n                  [message]=\"item.message\" [title]=\"item.title\">\n  </ui-modal-error>\n  <ui-modal-confirm *ngIf=\"item.type === 'confirm'\"\n                    (cancel)=\"modal.cancel(item)\" (close)=\"modal.close(item, $event)\" [icon]=\"item.icon\"\n                    [message]=\"item.message\" [title]=\"item.title\">\n  </ui-modal-confirm>\n  <ui-modal-prompt *ngIf=\"item.type === 'prompt'\"\n                   (cancel)=\"modal.cancel(item)\" (close)=\"modal.close(item, $event)\" [defaultValue]=\"item.data\"\n                   [icon]=\"item.icon\"\n                   [message]=\"item.message\" [title]=\"item.title\">\n  </ui-modal-prompt>\n  <ui-modal-form *ngIf=\"item.type === 'form'\"\n                 (cancel)=\"modal.cancel(item)\" (close)=\"modal.close(item, $event)\" [group]=\"item.data\"\n                 [icon]=\"item.icon\"\n                 [message]=\"item.message\" [title]=\"item.title\">\n  </ui-modal-form>\n  <ng-container *ngIf=\"item.type === 'custom'\">\n    <div [ngComponentOutletInjector]=\"injector\" [ngComponentOutlet]=\"item.customComponent\"\n         [uiDynamicComponentInputs]=\"[item.customInputs, {modal: item}]\"></div>\n  </ng-container>\n</ui-modal>\n",
            styles: [""]
        }),
        __metadata("design:paramtypes", [ModalService, Injector])
    ], ModalListComponent);
    return ModalListComponent;
}());

var ModalConfirmComponent = /** @class */ (function () {
    function ModalConfirmComponent() {
        this.close = new EventEmitter();
    }
    ModalConfirmComponent.prototype.ngOnInit = function () {
    };
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ModalConfirmComponent.prototype, "close", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalConfirmComponent.prototype, "title", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalConfirmComponent.prototype, "message", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalConfirmComponent.prototype, "icon", void 0);
    ModalConfirmComponent = __decorate([
        Component({
            selector: 'ui-modal-confirm',
            template: "<div class=\"modal-header bg-warning text-white\">\n  <h5 class=\"modal-title\">\n    {{title|default:'Confirm'}}\n  </h5>\n  <button (click)=\"close.emit(false)\" aria-label=\"Close\" class=\"close text-white\" tabindex=\"-1\"\n          type=\"button\">\n    <span aria-hidden=\"true\">&times;</span>\n  </button>\n</div>\n<div class=\"modal-body\">\n  <div class=\"row\">\n    <div class=\"col-auto\">\n      <i [ngClass]=\"icon|default:'fa-check-circle-o'\" class=\"fa fa-5x text-primary\"></i>\n    </div>\n    <div class=\"col\">\n      {{message}}\n    </div>\n  </div>\n</div>\n<div class=\"modal-footer\">\n  <button type=\"button\" class=\"btn btn-warning\" (click)=\"close.emit(true)\">\n    <span i18n>Yes</span>\n  </button>\n  <button type=\"button\" class=\"btn btn-secondary\" (click)=\"close.emit(false)\">\n    <span i18n>No</span>\n  </button>\n</div>\n",
            styles: [""]
        }),
        __metadata("design:paramtypes", [])
    ], ModalConfirmComponent);
    return ModalConfirmComponent;
}());

var ModalErrorComponent = /** @class */ (function () {
    function ModalErrorComponent() {
        this.close = new EventEmitter();
        this.cancel = new EventEmitter();
    }
    ModalErrorComponent.prototype.ngOnInit = function () {
    };
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ModalErrorComponent.prototype, "close", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ModalErrorComponent.prototype, "cancel", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalErrorComponent.prototype, "title", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalErrorComponent.prototype, "message", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalErrorComponent.prototype, "icon", void 0);
    ModalErrorComponent = __decorate([
        Component({
            selector: 'ui-modal-error',
            template: "<div class=\"modal-header bg-danger text-white\">\n  <h5 class=\"modal-title\">\n    {{title|default:'Error'}}\n  </h5>\n  <button (click)=\"cancel.emit()\" aria-label=\"Close\" class=\"close text-white\" tabindex=\"-1\" type=\"button\">\n    <span aria-hidden=\"true\">&times;</span>\n  </button>\n</div>\n<div class=\"modal-body\">\n  <div class=\"row\">\n    <div class=\"col-auto\">\n      <i [ngClass]=\"icon|default:'fa-times-circle'\" class=\"fa fa-5x text-danger\"></i>\n    </div>\n    <div class=\"col\">\n      {{message}}\n    </div>\n  </div>\n</div>\n<div class=\"modal-footer\">\n  <button type=\"button\" class=\"btn btn-danger\" (click)=\"close.emit()\">\n    <span i18n>Ok</span>\n  </button>\n</div>\n",
            styles: [""]
        }),
        __metadata("design:paramtypes", [])
    ], ModalErrorComponent);
    return ModalErrorComponent;
}());

var ModalFormComponent = /** @class */ (function () {
    function ModalFormComponent() {
        this.close = new EventEmitter();
        this.cancel = new EventEmitter();
    }
    ModalFormComponent.prototype.ngOnInit = function () {
    };
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ModalFormComponent.prototype, "close", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ModalFormComponent.prototype, "cancel", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalFormComponent.prototype, "title", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalFormComponent.prototype, "message", void 0);
    __decorate([
        Input(),
        __metadata("design:type", FormGroup)
    ], ModalFormComponent.prototype, "group", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalFormComponent.prototype, "icon", void 0);
    ModalFormComponent = __decorate([
        Component({
            selector: 'ui-modal-form',
            template: "<form (submit)=\"close.emit(group.value)\">\n  <div class=\"modal-header\">\n    <h5 class=\"modal-title\">\n      {{title|default:'Form'}}\n    </h5>\n    <button (click)=\"cancel.emit()\" aria-label=\"Close\" class=\"close\" tabindex=\"-1\" type=\"button\">\n      <span aria-hidden=\"true\">&times;</span>\n    </button>\n  </div>\n  <div class=\"modal-body\">\n    <div class=\"row\">\n      <div class=\"col-auto\">\n        <i [ngClass]=\"icon|default:'fa-pencil-square-o'\" class=\"fa fa-5x text-success\"></i>\n      </div>\n      <div class=\"col\">\n        <h4>{{message}}</h4>\n        <ui-form-group [group]=\"group\"></ui-form-group>\n      </div>\n    </div>\n  </div>\n  <div class=\"modal-footer\">\n    <button class=\"btn btn-primary\" type=\"submit\">\n      <span i18n>Submit</span>\n    </button>\n    <button (click)=\"cancel.emit()\" class=\"btn btn-secondary\" type=\"button\">\n      <span i18n>Cancel</span>\n    </button>\n  </div>\n</form>\n",
            styles: [""]
        }),
        __metadata("design:paramtypes", [])
    ], ModalFormComponent);
    return ModalFormComponent;
}());

var ModalInfoComponent = /** @class */ (function () {
    function ModalInfoComponent() {
        this.close = new EventEmitter();
        this.cancel = new EventEmitter();
    }
    ModalInfoComponent.prototype.ngOnInit = function () {
    };
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ModalInfoComponent.prototype, "close", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ModalInfoComponent.prototype, "cancel", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalInfoComponent.prototype, "title", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalInfoComponent.prototype, "message", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalInfoComponent.prototype, "icon", void 0);
    ModalInfoComponent = __decorate([
        Component({
            selector: 'ui-modal-info',
            template: "<div class=\"modal-header bg-info text-white\">\n  <h5 class=\"modal-title\">\n    {{title|default:'Info'}}\n  </h5>\n  <button (click)=\"cancel.emit()\" aria-label=\"Close\" class=\"close text-white\" tabindex=\"-1\" type=\"button\">\n    <span aria-hidden=\"true\">&times;</span>\n  </button>\n</div>\n<div class=\"modal-body\">\n  <div class=\"row\">\n    <div class=\"col-auto\">\n      <i [ngClass]=\"icon|default:'fa-info-circle'\" class=\"fa fa-5x text-info\"></i>\n    </div>\n    <div class=\"col\">\n      {{message}}\n    </div>\n  </div>\n</div>\n<div class=\"modal-footer\">\n  <button type=\"button\" class=\"btn btn-info\" (click)=\"close.emit()\">\n    <span i18n>Ok</span>\n  </button>\n</div>\n",
            styles: [""]
        }),
        __metadata("design:paramtypes", [])
    ], ModalInfoComponent);
    return ModalInfoComponent;
}());

var PromptModel = /** @class */ (function () {
    function PromptModel() {
    }
    __decorate([
        Property({
            label: '',
        }),
        __metadata("design:type", String)
    ], PromptModel.prototype, "result", void 0);
    PromptModel = __decorate([
        Model()
    ], PromptModel);
    return PromptModel;
}());
var ModalPromptComponent = /** @class */ (function () {
    function ModalPromptComponent(formMaker) {
        this.formMaker = formMaker;
        this.close = new EventEmitter();
        this.cancel = new EventEmitter();
        this.formGroup = this.formMaker.createFromModel(PromptModel);
    }
    Object.defineProperty(ModalPromptComponent.prototype, "defaultValue", {
        get: function () {
            return this.formGroup.value && this.formGroup.value.result;
        },
        set: function (value) {
            this.formGroup.setValue({ result: value || '' });
        },
        enumerable: true,
        configurable: true
    });
    ModalPromptComponent.prototype.ngOnInit = function () {
    };
    ModalPromptComponent.ctorParameters = function () { return [
        { type: FormMaker }
    ]; };
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ModalPromptComponent.prototype, "close", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ModalPromptComponent.prototype, "cancel", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalPromptComponent.prototype, "title", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalPromptComponent.prototype, "message", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalPromptComponent.prototype, "icon", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String),
        __metadata("design:paramtypes", [String])
    ], ModalPromptComponent.prototype, "defaultValue", null);
    ModalPromptComponent = __decorate([
        Component({
            selector: 'ui-modal-prompt',
            template: "<ui-modal-form (cancel)=\"cancel.emit()\" (close)=\"close.emit($event.result)\" [group]=\"formGroup\" [icon]=\"icon\"\n               [message]=\"message\" [title]=\"title|default:'Prompt'\">\n</ui-modal-form>\n",
            styles: [""]
        }),
        __metadata("design:paramtypes", [FormMaker])
    ], ModalPromptComponent);
    return ModalPromptComponent;
}());

var ModalSuccessComponent = /** @class */ (function () {
    function ModalSuccessComponent() {
        this.close = new EventEmitter();
        this.cancel = new EventEmitter();
    }
    ModalSuccessComponent.prototype.ngOnInit = function () {
    };
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ModalSuccessComponent.prototype, "close", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ModalSuccessComponent.prototype, "cancel", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalSuccessComponent.prototype, "title", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalSuccessComponent.prototype, "message", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalSuccessComponent.prototype, "icon", void 0);
    ModalSuccessComponent = __decorate([
        Component({
            selector: 'ui-modal-success',
            template: "<div class=\"modal-header bg-success text-white\">\n  <h5 class=\"modal-title\">\n    {{title|default:'Success'}}\n  </h5>\n  <button (click)=\"cancel.emit()\" aria-label=\"Close\" class=\"close text-white\" tabindex=\"-1\" type=\"button\">\n    <span aria-hidden=\"true\">&times;</span>\n  </button>\n</div>\n<div class=\"modal-body\">\n  <div class=\"row\">\n    <div class=\"col-auto\">\n      <i [ngClass]=\"icon|default:'fa-check-circle'\" class=\"fa fa-5x text-success\"></i>\n    </div>\n    <div class=\"col\">\n      {{message}}\n    </div>\n  </div>\n</div>\n<div class=\"modal-footer\">\n  <button type=\"button\" class=\"btn btn-success\" (click)=\"close.emit()\">\n    <span i18n>Ok</span>\n  </button>\n</div>\n",
            styles: [""]
        }),
        __metadata("design:paramtypes", [])
    ], ModalSuccessComponent);
    return ModalSuccessComponent;
}());

var ModalWarningComponent = /** @class */ (function () {
    function ModalWarningComponent() {
        this.close = new EventEmitter();
        this.cancel = new EventEmitter();
    }
    ModalWarningComponent.prototype.ngOnInit = function () {
    };
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ModalWarningComponent.prototype, "close", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ModalWarningComponent.prototype, "cancel", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalWarningComponent.prototype, "title", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalWarningComponent.prototype, "message", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], ModalWarningComponent.prototype, "icon", void 0);
    ModalWarningComponent = __decorate([
        Component({
            selector: 'ui-modal-warning',
            template: "<div class=\"modal-header bg-warning text-white\">\n  <h5 class=\"modal-title\">\n    {{title|default:'Warning'}}\n  </h5>\n  <button (click)=\"cancel.emit()\" aria-label=\"Close\" class=\"close text-white\" tabindex=\"-1\" type=\"button\">\n    <span aria-hidden=\"true\">&times;</span>\n  </button>\n</div>\n<div class=\"modal-body\">\n  <div class=\"row\">\n    <div class=\"col-auto\">\n      <i [ngClass]=\"icon|default:'fa-exclamation-circle'\" class=\"fa fa-5x text-warning\"></i>\n    </div>\n    <div class=\"col\">\n      {{message}}\n    </div>\n  </div>\n</div>\n<div class=\"modal-footer\">\n  <button type=\"button\" class=\"btn btn-warning\" (click)=\"close.emit()\">\n    <span i18n>Ok</span>\n  </button>\n</div>\n",
            styles: [""]
        }),
        __metadata("design:paramtypes", [])
    ], ModalWarningComponent);
    return ModalWarningComponent;
}());

var ModalComponent = /** @class */ (function () {
    function ModalComponent() {
        this.cancel = new EventEmitter();
    }
    ModalComponent.prototype.ngOnInit = function () {
    };
    ModalComponent.prototype.doCancel = function () {
        this.cancel.emit();
    };
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], ModalComponent.prototype, "cancel", void 0);
    ModalComponent = __decorate([
        Component({
            selector: 'ui-modal',
            template: "<div class=\"modal-backdrop fade\"></div>\n<div class=\"modal\">\n  <div class=\"modal-dialog\" role=\"document\">\n    <div class=\"modal-content\" (uiClickOutside)=\"doCancel()\">\n      <ng-content></ng-content>\n    </div>\n  </div>\n</div>\n",
            styles: [":host{display:block}.modal{display:block}.modal-backdrop{opacity:.5}"]
        })
    ], ModalComponent);
    return ModalComponent;
}());

var MultiSelectBoxComponent = /** @class */ (function () {
    function MultiSelectBoxComponent() {
    }
    MultiSelectBoxComponent.prototype.ngOnInit = function () {
    };
    MultiSelectBoxComponent = __decorate([
        Component({
            selector: 'ui-multi-select-box',
            template: "<p>\n  multi-select-box works!\n</p>\n",
            styles: [""]
        }),
        __metadata("design:paramtypes", [])
    ], MultiSelectBoxComponent);
    return MultiSelectBoxComponent;
}());

var PaginationComponent = /** @class */ (function () {
    function PaginationComponent() {
        this.showBrief = true;
        this.showPrevNext = true;
        this.showFirstLast = true;
    }
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], PaginationComponent.prototype, "showBrief", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], PaginationComponent.prototype, "showPrevNext", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], PaginationComponent.prototype, "showFirstLast", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Pagination)
    ], PaginationComponent.prototype, "pager", void 0);
    PaginationComponent = __decorate([
        Component({
            selector: 'ui-pagination',
            template: "<ul class=\"pagination\">\n  <li *ngIf=\"showFirstLast\" [class.disabled]=\"!pager.hasFirst\" class=\"page-item\">\n    <a (click)=\"pager.goToFirst()\" class=\"page-link\" href=\"javascript:void(0)\" title=\"First\">\n      <i class=\"fa fa-step-backward\"></i>\n    </a>\n  </li>\n  <li *ngIf=\"showPrevNext\" [class.disabled]=\"!pager.hasPrev\" class=\"page-item\">\n    <a (click)=\"pager.prev()\" class=\"page-link\" href=\"javascript:void(0)\" title=\"Prev\">\n      <i class=\"fa fa-backward\"></i>\n    </a>\n  </li>\n  <ng-container *ngIf=\"!pager.isEmpty\">\n    <li *ngFor=\"let page of pager.pages\" [class.active]=\"pager.isActive(page)\" class=\"page-item\">\n      <a (click)=\"pager.goTo(page)\" class=\"page-link\" href=\"javascript:void(0)\">{{page + 1}}</a>\n    </li>\n  </ng-container>\n  <li *ngIf=\"showPrevNext\" [class.disabled]=\"!pager.hasNext\" class=\"page-item\">\n    <a (click)=\"pager.next()\" class=\"page-link\" href=\"javascript:void(0)\" title=\"Next\">\n      <i class=\"fa fa-forward\"></i>\n    </a>\n  </li>\n  <li *ngIf=\"showFirstLast\" [class.disabled]=\"!pager.hasLast\" class=\"page-item\">\n    <a (click)=\"pager.goToLast()\" class=\"page-link\" href=\"javascript:void(0)\" title=\"Last\">\n      <i class=\"fa fa-step-forward\"></i>\n    </a>\n  </li>\n  <li *ngIf=\"showBrief\" class=\"page-item disabled\">\n    <span class=\"page-link\">\n      {{pager.totalItems}} items / {{pager.count}} pages\n    </span>\n  </li>\n</ul>\n",
            styles: [":host{display:block;margin-top:1rem;margin-bottom:1rem;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.pagination{margin:0}a:focus{box-shadow:none}"]
        })
    ], PaginationComponent);
    return PaginationComponent;
}());

var PanelComponent = /** @class */ (function () {
    function PanelComponent() {
        this.toggleable = true;
        this.toggle = new Toggle().setIsOn(Toggle.ON);
    }
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], PanelComponent.prototype, "title", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], PanelComponent.prototype, "toggleable", void 0);
    PanelComponent = __decorate([
        Component({
            selector: 'ui-panel',
            template: "<div class=\"card\">\n  <div *ngIf=\"title\" class=\"card-header\">\n    {{title}}\n    <i *ngIf=\"toggleable && toggle.isOn\" (click)=\"toggle.close()\" class=\"fa fa-chevron-up pull-right\"></i>\n    <i *ngIf=\"toggleable && toggle.isOff\" (click)=\"toggle.open()\" class=\"fa fa-chevron-down pull-right\"></i>\n  </div>\n  <div *ngIf=\"toggle.isOn\" class=\"card-body\">\n    <ng-content></ng-content>\n  </div>\n</div>\n",
            styles: [":host{display:block}.card-body{overflow:hidden}.card-header .icon{float:right}"]
        })
    ], PanelComponent);
    return PanelComponent;
}());

var RadioGroupWithinFormComponent = /** @class */ (function (_super) {
    __extends(RadioGroupWithinFormComponent, _super);
    function RadioGroupWithinFormComponent(container) {
        return _super.call(this, container) || this;
    }
    RadioGroupWithinFormComponent.ctorParameters = function () { return [
        { type: ControlContainer }
    ]; };
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], RadioGroupWithinFormComponent.prototype, "options", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], RadioGroupWithinFormComponent.prototype, "name", void 0);
    RadioGroupWithinFormComponent = __decorate([
        Component({
            selector: 'ui-radio-group-within-form',
            template: "<div [formGroup]=\"formGroup\">\n  <ui-radio-group [formControlName]=\"name\" [options]=\"options\"></ui-radio-group>\n</div>\n",
            styles: [":host{display:block}"]
        }),
        __metadata("design:paramtypes", [ControlContainer])
    ], RadioGroupWithinFormComponent);
    return RadioGroupWithinFormComponent;
}(BaseControlWithinForm));

var RadioGroupComponent = /** @class */ (function (_super) {
    __extends(RadioGroupComponent, _super);
    function RadioGroupComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.randomId = "" + new Date().getTime() + Math.floor(Math.random() * 10000);
        return _this;
    }
    RadioGroupComponent_1 = RadioGroupComponent;
    RadioGroupComponent.prototype.idOf = function (option) {
        return "checkbox-" + this.randomId + "-" + option[this.valueField];
    };
    var RadioGroupComponent_1;
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], RadioGroupComponent.prototype, "disabled", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], RadioGroupComponent.prototype, "valueField", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], RadioGroupComponent.prototype, "labelField", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], RadioGroupComponent.prototype, "options", void 0);
    RadioGroupComponent = RadioGroupComponent_1 = __decorate([
        Component({
            selector: 'ui-radio-group',
            template: "<div *ngFor=\"let option of options\" class=\"form-check form-check-inline\">\n  <input (change)=\"select(option)\" [checked]=\"selected(option)\" [disabled]=\"disabled\" [id]=\"idOf(option)\"\n         class=\"form-check-input\" type=\"radio\"/>\n  <label [for]=\"idOf(option)\" class=\"form-check-label\">\n    {{option[labelField]}}\n  </label>\n</div>\n",
            providers: [{
                    provide: NG_VALUE_ACCESSOR,
                    useExisting: RadioGroupComponent_1,
                    multi: true,
                }],
            styles: ["label{margin-right:.5em}"]
        })
    ], RadioGroupComponent);
    return RadioGroupComponent;
}(SelectValueAccessor));

var SelectBoxComponent = /** @class */ (function (_super) {
    __extends(SelectBoxComponent, _super);
    function SelectBoxComponent() {
        return _super.call(this) || this;
    }
    SelectBoxComponent_1 = SelectBoxComponent;
    SelectBoxComponent.prototype.ngOnInit = function () {
    };
    var SelectBoxComponent_1;
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], SelectBoxComponent.prototype, "options", void 0);
    SelectBoxComponent = SelectBoxComponent_1 = __decorate([
        Component({
            selector: 'ui-select-box',
            template: "<div class=\"dropdown\">\n  <ul class=\"dropdown-menu\">\n    <li *ngFor=\"let option of options\">\n      <a></a>\n    </li>\n  </ul>\n</div>\n",
            providers: [
                { provide: NG_VALUE_ACCESSOR, multi: true, useExisting: SelectBoxComponent_1 },
            ],
            styles: [""]
        }),
        __metadata("design:paramtypes", [])
    ], SelectBoxComponent);
    return SelectBoxComponent;
}(SelectValueAccessor));

var TableComponent = /** @class */ (function () {
    function TableComponent() {
        this.items = [];
        this.sorter = new TableSorter().setFields(this.fields);
        this.size = {};
        this._fields = [];
    }
    Object.defineProperty(TableComponent.prototype, "fields", {
        get: function () {
            return this._fields;
        },
        set: function (value) {
            if (this._fields !== value) {
                this._fields = value;
                this.sorter.fields = value;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableComponent.prototype, "sortable", {
        get: function () {
            return this.sorter.enabled;
        },
        set: function (value) {
            this.sorter.enabled = value;
        },
        enumerable: true,
        configurable: true
    });
    TableComponent.prototype.orderCss = function (order) {
        switch (order) {
            case SortOrder.Asc:
                return 'fa-sort-asc';
            case SortOrder.Desc:
                return 'fa-sort-desc';
            case SortOrder.None:
            default:
                return 'fa-sort';
        }
    };
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], TableComponent.prototype, "items", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array),
        __metadata("design:paramtypes", [Array])
    ], TableComponent.prototype, "fields", null);
    __decorate([
        Input(),
        __metadata("design:type", Boolean),
        __metadata("design:paramtypes", [Boolean])
    ], TableComponent.prototype, "sortable", null);
    TableComponent = __decorate([
        Component({
            selector: 'ui-table',
            template: "<ng-container *ngIf=\"sorter\" #pager=\"uiPagination\" [totalItems]=\"items.length\" uiPagination>\n  <table class=\"table table-hover table-striped table-bordered\">\n    <thead>\n    <tr>\n      <th *ngFor=\"let field of fields\" #measure=\"uiMeasure\"\n          (click)=\"sorter.toggle(field)\" [class.sortable]=\"sortable && field.sortable\"\n          [ngClass]=\"field.type|typeName:'data-type-'\"\n          [style.width.px]=\"(measure.clientRect.width + movable.offset.x)||100\"\n          [title]=\"field.title\"\n          class=\"resizable\" uiMeasure>\n        {{field.title}}\n        <i *ngIf=\"field.sortable\" [ngClass]=\"orderCss(field.sortOrder)\" class=\"fa\"></i>\n        <div #movable=\"uiMovable\" (uiMoveStop)=\"measure.update()\" class=\"splitter\" uiMovable></div>\n      </th>\n    </tr>\n    </thead>\n    <tbody>\n    <tr *ngFor=\"let item of items | orderBy:sorter | slice:pager.begin:pager.end\">\n      <td *ngFor=\"let field of fields\" [ngClass]=\"field.type|typeName:'data-type-'\">\n        <span [title]=\"item[field.name]|format:field\">{{item[field.name]|format:field}}</span>\n      </td>\n    </tr>\n    </tbody>\n  </table>\n\n  <div class=\"row\">\n    <div class=\"col-md-10\">\n      <ui-pagination [pager]=\"pager\" [showBrief]=\"false\"></ui-pagination>\n    </div>\n    <div class=\"col-md-2\">\n      <select [(ngModel)]=\"pager.size\" class=\"form-control\" name=\"pageSize\">\n        <option value=\"10\">10</option>\n        <option value=\"20\">20</option>\n        <option value=\"50\">50</option>\n      </select>\n    </div>\n  </div>\n</ng-container>\n",
            styles: ["@charset \"UTF-8\";:host{display:block}table{table-layout:fixed}table th{min-width:100px}.data-type-currency,.data-type-float,.data-type-int{text-align:right}th.sortable{cursor:pointer}th.sortable>.fa-sort-none{display:inline-block;font:14px/1 FontAwesome;font-size:inherit;text-rendering:auto;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}th.sortable>.fa-sort-none:after{content:\"\uF0DC\"}th.sortable>.fa-sort-asc,th.sortable>.fa-sort-desc{display:inline-block;font:14px/1 FontAwesome;font-size:inherit;text-rendering:auto;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}td>[title],th>[title]{display:block;text-overflow:ellipsis;white-space:nowrap;overflow:hidden}ui-pagination{margin:0}.resizable{position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;white-space:nowrap;overflow:hidden}.resizable>.splitter{z-index:100;position:absolute;right:-3px;top:0;bottom:0;width:5px;background:rgba(0,0,0,.01);cursor:ew-resize}"]
        })
    ], TableComponent);
    return TableComponent;
}());

var ToastListComponent = /** @class */ (function () {
    function ToastListComponent(toast) {
        this.toast = toast;
    }
    ToastListComponent.prototype.ngOnInit = function () {
    };
    ToastListComponent.ctorParameters = function () { return [
        { type: ToastService }
    ]; };
    ToastListComponent = __decorate([
        Component({
            selector: 'ui-toast-list',
            template: "<div *ngIf=\"!toast.isEmpty\" class=\"tooltip\">\n  <div *ngFor=\"let item of toast.items\" class=\"tooltip-inner bg-success text-light mb-2\">\n    {{item.message}} ({{item.duration / 1000 | number:'1.0-0'}})\n  </div>\n</div>\n",
            styles: [".tooltip{position:fixed;left:0;right:0;top:20vh;margin:auto;width:15em;opacity:1}"]
        }),
        __metadata("design:paramtypes", [ToastService])
    ], ToastListComponent);
    return ToastListComponent;
}());

var TooltipComponent = /** @class */ (function () {
    function TooltipComponent(tooltip) {
        this.tooltip = tooltip;
        this.rect = new Rect();
    }
    TooltipComponent.prototype.resize = function ($event) {
        this.rect = this.tooltip.getRectFor($event.boundingClientRect);
    };
    TooltipComponent.ctorParameters = function () { return [
        { type: TooltipService }
    ]; };
    TooltipComponent = __decorate([
        Component({
            selector: 'ui-tooltip',
            template: "<div (uiMeasure)=\"resize($event)\" [style.left.px]=\"rect.left\" [style.top.px]=\"rect.top\"\n     class=\"tooltip bs-tooltip-bottom\">\n  <div class=\"arrow\"></div>\n  <div class=\"tooltip-inner\">\n    <ng-content></ng-content>\n  </div>\n</div>\n",
            styles: [":host{display:block}.tooltip{position:fixed;opacity:1}.tooltip.bs-tooltip-bottom .arrow{left:50%}"]
        }),
        __metadata("design:paramtypes", [TooltipService])
    ], TooltipComponent);
    return TooltipComponent;
}());

var TreeNodeComponent = /** @class */ (function () {
    function TreeNodeComponent() {
        this.toggle = new Toggle().setIsOn(Toggle.ON);
    }
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], TreeNodeComponent.prototype, "data", void 0);
    TreeNodeComponent = __decorate([
        Component({
            selector: 'ui-tree-node',
            template: "<ng-container *ngIf=\"data\">\n  <i *ngIf=\"data.items?.length && toggle.isOff\" (click)=\"toggle.open()\" class=\"fa fa-plus-square-o\"></i>\n  <i *ngIf=\"data.items?.length && toggle.isOn\" (click)=\"toggle.close()\" class=\"fa fa-minus-square-o\"></i>\n  <label>{{data.label}}</label>\n  <ul *ngIf=\"data && toggle.isOn\">\n    <li *ngFor=\"let item of data.items\">\n      <ui-tree-node [data]=\"item\"></ui-tree-node>\n    </li>\n  </ul>\n</ng-container>\n",
            styles: [":host{display:block}ul{list-style:none;padding-left:2em}img{height:1em;vertical-align:baseline}"]
        })
    ], TreeNodeComponent);
    return TreeNodeComponent;
}());

var TypeAheadWithinFormComponent = /** @class */ (function (_super) {
    __extends(TypeAheadWithinFormComponent, _super);
    function TypeAheadWithinFormComponent(container) {
        return _super.call(this, container) || this;
    }
    TypeAheadWithinFormComponent.ctorParameters = function () { return [
        { type: ControlContainer }
    ]; };
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], TypeAheadWithinFormComponent.prototype, "options", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], TypeAheadWithinFormComponent.prototype, "name", void 0);
    TypeAheadWithinFormComponent = __decorate([
        Component({
            selector: 'ui-type-ahead-within-form',
            template: "<div [formGroup]=\"formGroup\">\n  <ui-type-ahead [formControlName]=\"name\" [items]=\"options\"></ui-type-ahead>\n</div>\n",
            styles: [":host{display:block}ui-type-ahead{display:block}"]
        }),
        __metadata("design:paramtypes", [ControlContainer])
    ], TypeAheadWithinFormComponent);
    return TypeAheadWithinFormComponent;
}(BaseControlWithinForm));

var TypeAheadComponent = /** @class */ (function () {
    function TypeAheadComponent() {
        this.dropDown = new Toggle();
        this.checker = new Subject();
        this.displayField = 'name';
        this.placeholder = '-';
        this.formatter = this.defaultFormatter.bind(this);
        this.parser = this.defaultParser.bind(this);
        this.search = new EventEmitter();
        this.activeIndex = 0;
        this.term = '';
        this.disabled = false;
    }
    TypeAheadComponent_1 = TypeAheadComponent;
    Object.defineProperty(TypeAheadComponent.prototype, "value", {
        get: function () {
            return this._value;
        },
        set: function (value) {
            this._value = value;
            this.term = value && this.parser(value);
        },
        enumerable: true,
        configurable: true
    });
    TypeAheadComponent.prototype.defaultFormatter = function (value) {
        if (!value) {
            return '';
        }
        if (value.hasOwnProperty('format') && isFunction$1(value.format)) {
            return value.format();
        }
        else {
            return value[this.displayField];
        }
    };
    TypeAheadComponent.prototype.defaultParser = function (value) {
        if (!value) {
            return '';
        }
        if (value.hasOwnProperty('parse') && isFunction$1(value.format)) {
            return value.parse();
        }
        else {
            return value[this.displayField];
        }
    };
    TypeAheadComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.sub = this.checker.asObservable().pipe(skipWhile(function (term) { return !term; }), debounceTime(200), tap(function () {
            _this.search.emit(_this.term);
        })).subscribe(function () {
            _this.dropDown.open();
        });
    };
    TypeAheadComponent.prototype.ngOnDestroy = function () {
        this.checker.complete();
        this.sub.unsubscribe();
    };
    TypeAheadComponent.prototype.writeValue = function (value) {
        this.value = value;
    };
    TypeAheadComponent.prototype.registerOnChange = function (fn) {
        this._change = fn;
    };
    TypeAheadComponent.prototype.registerOnTouched = function (fn) {
        this._touched = fn;
    };
    TypeAheadComponent.prototype.setDisabledState = function (isDisabled) {
        this.disabled = isDisabled;
    };
    TypeAheadComponent.prototype.select = function (item) {
        this.value = item;
        this.changed();
    };
    TypeAheadComponent.prototype.clear = function () {
        this.select(undefined);
    };
    TypeAheadComponent.prototype.keydown = function ($event) {
        if (['ArrowUp', 'ArrowDown', 'Home', 'End'].indexOf($event.key) !== -1) {
            $event.preventDefault();
            $event.stopPropagation();
        }
    };
    TypeAheadComponent.prototype.keyup = function ($event) {
        var count = this.items.length;
        switch ($event.key) {
            case 'ArrowDown':
                this.activeIndex = (this.activeIndex + 1) % count;
                break;
            case 'ArrowUp':
                this.activeIndex = (this.activeIndex + count - 1) % count;
                break;
            case 'Home':
                this.activeIndex = 0;
                break;
            case 'End':
                this.activeIndex = count - 1;
                break;
            default:
                return;
        }
        $event.preventDefault();
        $event.stopPropagation();
    };
    TypeAheadComponent.prototype.keypress = function ($event) {
        if ($event.key === 'Enter') {
            this.select(this.items[this.activeIndex]);
            this.dropDown.close();
            $event.preventDefault();
            $event.stopPropagation();
        }
    };
    TypeAheadComponent.prototype.changed = function () {
        if (this._change) {
            this._change(this.value);
        }
    };
    var TypeAheadComponent_1;
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], TypeAheadComponent.prototype, "items", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], TypeAheadComponent.prototype, "displayField", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], TypeAheadComponent.prototype, "placeholder", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Function)
    ], TypeAheadComponent.prototype, "formatter", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Function)
    ], TypeAheadComponent.prototype, "parser", void 0);
    __decorate([
        Output(),
        __metadata("design:type", Object)
    ], TypeAheadComponent.prototype, "search", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], TypeAheadComponent.prototype, "disabled", void 0);
    TypeAheadComponent = TypeAheadComponent_1 = __decorate([
        Component({
            selector: 'ui-type-ahead',
            template: "<div (uiClickOutside)=\"dropDown.close()\">\n  <div class=\"input-group\">\n    <input #typeAhead=\"uiTypeAhead\" (keydown)=\"keydown($event)\" (keypress)=\"keypress($event)\"\n           (keyup)=\"keyup($event)\" (uiTypeAheadClose)=\"dropDown.close()\" (uiTypeAheadOpen)=\"dropDown.open()\"\n           (uiTypeAheadSearch)=\"search.emit($event)\" [(ngModel)]=\"term\" class=\"form-control\"\n           name=\"term\" type=\"text\" uiTypeAhead\n    />\n    <div class=\"input-group-append\">\n      <button (click)=\"clear()\" class=\"btn btn-primary\" type=\"button\">X</button>\n    </div>\n  </div>\n  <div *ngIf=\"dropDown.isOn\" class=\"dropdown-menu\">\n    <div *ngIf=\"!items.length\" class=\"dropdown-item not-found\">{{placeholder}}</div>\n    <div *ngFor=\"let item of items; let index = index\" (click)=\"select(item);dropDown.close()\"\n         [class.active]=\"index === activeIndex\"\n         [innerHTML]=\"formatter(item)\"\n         class=\"dropdown-item\">\n    </div>\n  </div>\n</div>\n\n",
            providers: [{
                    provide: NG_VALUE_ACCESSOR,
                    useExisting: TypeAheadComponent_1,
                    multi: true,
                }],
            styles: [":host{display:inline-block;position:relative}.dropdown-menu{display:block;width:100%;top:initial}.dropdown-item.not-found{color:#dc3545}"]
        })
    ], TypeAheadComponent);
    return TypeAheadComponent;
}());

var FieldCssPipe = /** @class */ (function () {
    function FieldCssPipe() {
    }
    FieldCssPipe.prototype.transform = function (field) {
        if (!field) {
            return '';
        }
        var cssList = ['ui-model-field', "ui-model-field-" + field.name];
        if (field.css) {
            if (isDevMode()) {
                console.warn('You specified a custom css, so I no longer automatically add `col-md-*` class.');
            }
            cssList.push(field.css);
        }
        else {
            if (field.isGroup || field.isArray) {
                cssList.push('col-md-12');
            }
            else {
                cssList.push('col-md-6');
            }
        }
        return cssList.join(' ');
    };
    FieldCssPipe = __decorate([
        Pipe({
            name: 'fieldCss',
        })
    ], FieldCssPipe);
    return FieldCssPipe;
}());

var UiModelBootstrapModule = /** @class */ (function () {
    function UiModelBootstrapModule() {
    }
    UiModelBootstrapModule = __decorate([
        NgModule({
            imports: [
                CommonModule,
                FormsModule,
                ReactiveFormsModule,
                UiModelModule,
            ],
            declarations: [
                ModalComponent,
                ModalSuccessComponent,
                ModalInfoComponent,
                ModalErrorComponent,
                ModalConfirmComponent,
                ModalFormComponent,
                ModalPromptComponent,
                ModalWarningComponent,
                PaginationComponent,
                PanelComponent,
                RadioGroupComponent,
                RadioGroupWithinFormComponent,
                TableComponent,
                TreeNodeComponent,
                CalendarComponent,
                TypeAheadComponent,
                TypeAheadWithinFormComponent,
                TooltipComponent,
                FieldErrorComponent,
                FormGroupComponent,
                FormArrayComponent,
                FormControlComponent,
                DatePickerComponent,
                SelectBoxComponent,
                MultiSelectBoxComponent,
                FieldCssPipe,
                ModalListComponent,
                ToastListComponent,
            ],
            exports: [
                ModalComponent,
                ModalSuccessComponent,
                ModalInfoComponent,
                ModalErrorComponent,
                ModalFormComponent,
                ModalConfirmComponent,
                ModalPromptComponent,
                ModalWarningComponent,
                PaginationComponent,
                PanelComponent,
                RadioGroupComponent,
                RadioGroupWithinFormComponent,
                TableComponent,
                TreeNodeComponent,
                CalendarComponent,
                TypeAheadComponent,
                TypeAheadWithinFormComponent,
                TooltipComponent,
                FieldErrorComponent,
                FormGroupComponent,
                FormArrayComponent,
                FormControlComponent,
                DatePickerComponent,
                SelectBoxComponent,
                ModalListComponent,
                ToastListComponent,
                FieldCssPipe,
            ],
        })
    ], UiModelBootstrapModule);
    return UiModelBootstrapModule;
}());

/*
 * Public API Surface of angular-bootstrap
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CalendarComponent, DatePickerComponent, FieldCssPipe, FieldErrorComponent, FormArrayComponent, FormControlComponent, FormGroupComponent, ModalComponent, ModalConfirmComponent, ModalErrorComponent, ModalFormComponent, ModalInfoComponent, ModalListComponent, ModalPromptComponent, ModalSuccessComponent, ModalWarningComponent, PaginationComponent, PanelComponent, RadioGroupComponent, RadioGroupWithinFormComponent, SelectBoxComponent, TableComponent, ToastListComponent, TooltipComponent, TreeNodeComponent, TypeAheadComponent, TypeAheadWithinFormComponent, UiModelBootstrapModule, MultiSelectBoxComponent as ɵa };
//# sourceMappingURL=ui-model-angular-bootstrap.js.map
